# Deploying to the WS Test Environment

## Two Types of Test Deployments
While Workspaces development is handled in an Agile manner, the release cycle itself is handled through
waterfall, partially due to frequent reliance on AAT/PPI and VLASS release cycles. A WS Release Candidate will be
made available for acceptance testing by the WS Stakeholders at TRR stage (after final sprint review)
and then go through integrated Stakeholder testing and ORR stage before being approved for Production
Deployment.

## End of Sprint Deployment (Feature Testing)

#### At the end of each WS Sprint:

<span style="color:indianred">
** If development for a sprint was done on a DEVELOPMENT branch, DO NOT TAG END OF SPRINT**
</span>


* Run any needed schema migrations against the test database: 
<span style="color:cornflowerblue">
docker compose -f docker-compose.local.yml --profile schema-test up schema-test
</span>
* Update any needed Capo properties
* Tag main branch as:
  <span style="color:cornflowerblue">
  end-of-sprint-{#sprint}
  </span>
    * This tag is then automatically pushed up to the testing server as part of the WS CI/CD pipeline.
* Ensure test PEXes have been updated on the cluster after deployment to test. Check the build dates
in the workspaces/sbin/ area.

You should now be ready for Sprint Review.

## Release Candidate Deployment (WS TRR)

#### After Final Sprint Close:
* Create a DEVELOPMENT branch for work on the next version: <span style="color:cornflowerblue">{#version}-DEVELOPMENT</span>
  * It might be necessary to fix bugs found during Stakeholder testing, but we also don't want to pollute
  the release candidate in main with any ongoing work for the next release. This will be merged back into main after 
  production deployment of the version under acceptance testing.

* Verify that the test database already has the expected migrations in place.

* Verify <span style="color:cornflowerblue">dsoc-test</span> Capo properties

* Tag the release candidate branch: <span style="color:cornflowerblue">{#version}-rc1</span>
  * This tag will then autodeploy to the testing server as part of the WS CI/CD pipeline.

* Ensure test PEXes have been properly updated on the cluster.
  * Check the build dates in the workspaces/sbin/ area.
  * If ingest changes were made, ensure the current PEX was copied over from the dev environment.

* Notify the Product Owner(s) (John Tobin (WS), Mark Lacy(SRDP), Amy Kimball(VLASS)) that the release candidate has
been deployed to test and is available for integrated testing. Note: WS, AAT, and VLASS will 
usually end up being tested together due to functionality interdependence.

You should now be ready for Stakeholder Testing.
